@@ -5,19 +5,23 @@
  *
  * @package PhpMyAdmin
  */
+use PMA\libraries\config\PageSettings;
 
 /**
  *
  */
 require_once 'libraries/common.inc.php';
+require_once 'libraries/config/user_preferences.forms.php';
+require_once 'libraries/config/page_settings.forms.php';
+
+PageSettings::showGroup('Sql_queries');
 
 /**
  * Runs common work
  */
-$response = PMA_Response::getInstance();
+$response = PMA\libraries\Response::getInstance();
 $header   = $response->getHeader();
 $scripts  = $header->getScripts();
-$scripts->addFile('functions.js');
 $scripts->addFile('makegrid.js');
 $scripts->addFile('jquery/jquery.uitablefilter.js');
 $scripts->addFile('sql.js');
@@ -41,5 +45,3 @@ $response->addHTML(
         : ';'
     )
 );
-
-?>
